@@ -10,6 +10,10 @@ use JSON;
 
 App::gh::Command::Pull - pull changes from other forks.
 
+=head1 USAGE
+
+    $ gh pull [id]
+
 =cut
 
 sub options { (
@@ -37,7 +41,7 @@ sub run {
 
     die "git config not found." if  ! -e ".git/config" ;
 
-    my $fork_branch_name = "$acc/$from_branch";
+    my $fork_branch_name = "$acc-$from_branch";
     my $current_repo = $self->get_current_repo();
     my $fork_uri = $self->gen_uri( $acc , $current_repo );
 
